@@ -86,12 +86,22 @@ prepare_param_in_pxe_cfg(){
        use_modified_init="no"
        append_param_in_pxe_cfg="initrd=$nbi_initrd"
        ;;
-    clonezilla-live|gparted-live)
+    clonezilla-live)
        # Find the IP address of this server. Here we choose the first one in the list, since it's just an example.
        server_IP="$(LC_ALL=C get-all-nic-ip -i | awk -F" " '{print $1}')"
        if [ -z "$cl_gp_boot_param" ]; then
 	 # We do not put ip=frommedia because the /etc/resolv.conf got in live-initramfs won't exist after initramfs is done.        
-         append_param_in_pxe_cfg="initrd=$nbi_initrd boot=live union=aufs noswap noprompt nolocales vga=788 fetch=tftp://$server_IP/$squashfs_file"
+         append_param_in_pxe_cfg="initrd=$nbi_initrd boot=live union=aufs noswap noprompt nolocales vga=788 fetch=tftp://$server_IP/$squashfs_file ocs_server=\"$server_IP\""
+       else
+         append_param_in_pxe_cfg="initrd=$nbi_initrd $cl_gp_boot_param noprompt fetch=tftp://$server_IP/$squashfs_file ocs_server=\"$server_IP\""
+       fi
+       ;;
+    gparted-live)
+       # Find the IP address of this server. Here we choose the first one in the list, since it's just an example.
+       server_IP="$(LC_ALL=C get-all-nic-ip -i | awk -F" " '{print $1}')"
+       if [ -z "$cl_gp_boot_param" ]; then
+	 # We do not put ip=frommedia because the /etc/resolv.conf got in live-initramfs won't exist after initramfs is done.        
+         append_param_in_pxe_cfg="initrd=$nbi_initrd boot=live union=aufs noswap noprompt nolocales vga=788 fetch=tftp://$server_IP/$squashfs_file "
        else
          append_param_in_pxe_cfg="initrd=$nbi_initrd $cl_gp_boot_param noprompt fetch=tftp://$server_IP/$squashfs_file"
        fi
